==> jc-1.4.0.tar.gz: java/util/WeakHashMap__24WeakEntrySet__241.h <==
// final class java.util.WeakHashMap$WeakEntrySet$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a6eebcca3001d693 java_util_WeakHashMap__24WeakEntrySet__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_WeakHashMap__24WeakEntrySet__241_H_
#define _JC_java_util_WeakHashMap__24WeakEntrySet__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object;
struct _jc_java_util_WeakHashMap__24WeakEntrySet$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$refs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object	_jc_java_util_WeakHashMap__24WeakEntrySet__241$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$_init$9a5db7584fb3b222(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *);

// Virtual methods
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$checkMod$3aefa88ab86bd6ab(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
extern struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *_jc_java_util_WeakHashMap__24WeakEntrySet__241$method$findNext$4b1c13fb2edd8eda(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
extern jboolean _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakEntrySet__241$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$checkMod$3aefa88ab86bd6ab;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$findNext$4b1c13fb2edd8eda;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods {
	void	(*checkMod$3aefa88ab86bd6ab)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*(*findNext$4b1c13fb2edd8eda)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *);
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *);
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods	java_util_WeakHashMap__24WeakEntrySet__241;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs {
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*lastEntry;
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*nextEntry;
	struct _jc_java_util_WeakHashMap__24WeakEntrySet$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$refs {
    _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs	java_util_WeakHashMap__24WeakEntrySet__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs {
	jint	knownMod;
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs	java_util_WeakHashMap__24WeakEntrySet__241;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object {
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype _jc_java_util_WeakHashMap__24WeakEntrySet__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakEntrySet__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakEntrySet__241$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakEntrySet__241_H_ */

==> jc-1.4.6.tar.gz: java/util/WeakHashMap__24WeakEntrySet__241.h <==
// final class java.util.WeakHashMap$WeakEntrySet$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a6eebcca3001d693 java_util_WeakHashMap__24WeakEntrySet__241

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_WeakHashMap__24WeakEntrySet__241_H_
#define _JC_java_util_WeakHashMap__24WeakEntrySet__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object;
struct _jc_java_util_WeakHashMap__24WeakEntrySet$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$refs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs	_jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object	_jc_java_util_WeakHashMap__24WeakEntrySet__241$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$_init$9a5db7584fb3b222(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *, struct _jc_java_util_WeakHashMap__24WeakEntrySet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$checkMod$3aefa88ab86bd6ab(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *_jc_java_util_WeakHashMap__24WeakEntrySet__241$method$findNext$4b1c13fb2edd8eda(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$hasNext$fb0bd5e38c59ddcd(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_WeakHashMap__24WeakEntrySet__241$method$next$05874f79a1cf66ea(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$remove$fd50149979e1f350(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_WeakHashMap__24WeakEntrySet__241$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$checkMod$3aefa88ab86bd6ab;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$findNext$4b1c13fb2edd8eda;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$hasNext$fb0bd5e38c59ddcd;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$next$05874f79a1cf66ea;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$remove$fd50149979e1f350;
extern _jc_method _jc_java_util_WeakHashMap__24WeakEntrySet__241$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods {
	void	(*checkMod$3aefa88ab86bd6ab)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*(*findNext$4b1c13fb2edd8eda)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *, struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *) _JC_JCNI_ATTR;
	jboolean	(*hasNext$fb0bd5e38c59ddcd)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*next$05874f79a1cf66ea)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
	void	(*remove$fd50149979e1f350)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vmethods	java_util_WeakHashMap__24WeakEntrySet__241;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs {
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*lastEntry;
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*nextEntry;
	struct _jc_java_util_WeakHashMap__24WeakEntrySet$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$refs {
    _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_refs	java_util_WeakHashMap__24WeakEntrySet__241;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs {
	jint	knownMod;
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_WeakHashMap__24WeakEntrySet__241$sub_nonrefs	java_util_WeakHashMap__24WeakEntrySet__241;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakEntrySet__241$object {
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakEntrySet__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakEntrySet__241$vtype _jc_java_util_WeakHashMap__24WeakEntrySet__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakEntrySet__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakEntrySet__241$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakEntrySet__241_H_ */
